@@ -1,26 +1,40 @@
 package JIRA::REST::Class::Issue::Changelog::Change::Item;
-use base qw( JIRA::REST::Class::Abstract );
+use parent qw( JIRA::REST::Class::Abstract );
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 
 use JIRA::REST::Class::Version qw( $VERSION );
 
-# ABSTRACT: A helper class for C<JIRA::REST::Class> that represents an individual item in an individual change to a JIRA issue as an object.
+# ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents an individual item in an individual change to a JIRA issue as an object.
 
-__PACKAGE__->mk_data_ro_accessors(qw/ field fieldtype
-                                      from fromString
-                                      to toString /);
+__PACKAGE__->mk_data_ro_accessors(
+    qw/ field fieldtype from fromString to toString / ##
+);
 
 1;
 
+#pod =accessor B<field>
+#pod
+#pod =accessor B<fieldtype>
+#pod
+#pod =accessor B<from>
+#pod
+#pod =accessor B<fromString>
+#pod
+#pod =accessor B<to>
+#pod
+#pod =accessor B<toString>
+#pod
+#pod =cut
+
 __END__
 
 =pod
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexey Melezhik Atlassian JRC ScriptRunner TODO
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian GreenHopper JRC ScriptRunner TODO
 aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
 assigneeType avatar avatarUrls completeDate displayName duedate
 emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
@@ -33,11 +47,11 @@ toString updateAuthor worklog workratio
 
 =head1 NAME
 
-JIRA::REST::Class::Issue::Changelog::Change::Item - A helper class for C<JIRA::REST::Class> that represents an individual item in an individual change to a JIRA issue as an object.
+JIRA::REST::Class::Issue::Changelog::Change::Item - A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents an individual item in an individual change to a JIRA issue as an object.
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 READ-ONLY ACCESSORS
 
@@ -53,6 +67,18 @@ version 0.04
 
 =head2 B<toString>
 
+=head1 RELATED CLASSES
+
+=over 2
+
+=item * L<JIRA::REST::Class|JIRA::REST::Class>
+
+=item * L<JIRA::REST::Class::Abstract|JIRA::REST::Class::Abstract>
+
+=item * L<JIRA::REST::Class::Version|JIRA::REST::Class::Version>
+
+=back
+
 =head1 AUTHOR
 
 Packy Anderson <packy@cpan.org>
