@@ -1,21 +1,23 @@
 package JIRA::REST::Class::Issue::TimeTracking;
-use base qw( JIRA::REST::Class::Abstract );
+use parent qw( JIRA::REST::Class::Abstract );
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 
 use JIRA::REST::Class::Version qw( $VERSION );
 
-# ABSTRACT: A helper class for C<JIRA::REST::Class> that represents the time tracking for a JIRA issue as an object.
+# ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents the time tracking for a JIRA issue as an object.
 
 use Contextual::Return;
 
 sub init {
     my $self = shift;
-    $self->SUPER::init(@_);
+    $self->SUPER::init( @_ );
 
-    my $data = $self->issue->get(q{}, { fields => 'timetracking' });
+    my $data = $self->issue->get( q{}, { fields => 'timetracking' } );
     $self->{data} = $data->{fields}->{timetracking};
+
+    return;
 }
 
 #pod =accessor B<originalEstimate>
@@ -26,10 +28,12 @@ sub init {
 
 sub originalEstimate {
     my $self = shift;
+    #<<<
     return
         NUM { $self->data->{originalEstimateSeconds} }
         STR { $self->data->{originalEstimate} }
     ;
+    #>>>
 }
 
 #pod =accessor B<remainingEstimate>
@@ -40,10 +44,12 @@ sub originalEstimate {
 
 sub remainingEstimate {
     my $self = shift;
+    #<<<
     return
         NUM { $self->data->{remainingEstimateSeconds} }
         STR { $self->data->{remainingEstimate} }
     ;
+    #>>>
 }
 
 #pod =accessor B<timeSpent>
@@ -54,10 +60,12 @@ sub remainingEstimate {
 
 sub timeSpent {
     my $self = shift;
+    #<<<
     return
         NUM { $self->data->{timeSpentSeconds} }
         STR { $self->data->{timeSpent} }
     ;
+    #>>>
 }
 
 #pod =method B<set_originalEstimate>
@@ -69,7 +77,7 @@ sub timeSpent {
 sub set_originalEstimate {
     my $self = shift;
     my $est  = shift;
-    $self->update( { originalEstimate => $est } );
+    return $self->update( { originalEstimate => $est } );
 }
 
 #pod =method B<set_remainingEstimate>
@@ -81,7 +89,7 @@ sub set_originalEstimate {
 sub set_remainingEstimate {
     my $self = shift;
     my $est  = shift;
-    $self->update( { remainingEstimate => $est } );
+    return $self->update( { remainingEstimate => $est } );
 }
 
 #pod =method B<update>
@@ -94,19 +102,20 @@ sub update {
     my $self   = shift;
     my $update = shift;
 
-    foreach my $key (qw/ originalEstimate remainingEstimate /) {
+    foreach my $key ( qw/ originalEstimate remainingEstimate / ) {
+
         # if we're updating the key, don't change it
         next if exists $update->{$key};
 
         # since we're not updating the key, copy the original value
         # into the update, because the REST interface has an annoying
         # tendency to reset those values if you don't explicitly set them
-        if (defined $self->data->{$key}) {
+        if ( defined $self->data->{$key} ) {
             $update->{$key} = $self->data->{$key};
         }
     }
 
-    $self->issue->put_field( timetracking => $update );
+    return $self->issue->put_field( timetracking => $update );
 }
 
 1;
@@ -117,7 +126,7 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexey Melezhik Atlassian JRC ScriptRunner TODO
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian GreenHopper JRC ScriptRunner TODO
 aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
 assigneeType avatar avatarUrls completeDate displayName duedate
 emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
@@ -130,25 +139,11 @@ toString updateAuthor worklog workratio
 
 =head1 NAME
 
-JIRA::REST::Class::Issue::TimeTracking - A helper class for C<JIRA::REST::Class> that represents the time tracking for a JIRA issue as an object.
+JIRA::REST::Class::Issue::TimeTracking - A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents the time tracking for a JIRA issue as an object.
 
 =head1 VERSION
 
-version 0.04
-
-=head1 READ-ONLY ACCESSORS
-
-=head2 B<originalEstimate>
-
-Returns the original estimate as a number of seconds in numeric context, and as a w/d/h/m/s string in a string context.
-
-=head2 B<remainingEstimate>
-
-Returns the remaining estimate as a number of seconds in numeric context, and as a w/d/h/m/s string in a string context.
-
-=head2 B<timeSpent>
-
-Returns the time spent as a number of seconds in numeric context, and as a w/d/h/m/s string in a string context.
+version 0.05
 
 =head1 METHODS
 
@@ -164,6 +159,32 @@ Sets the remaining estimate to the amount of time given.  Accepts any time forma
 
 Accepts a hashref of timetracking fields to update. The acceptable fields are determined by JIRA, but I think they're originalEstimate and remainingEstimate.
 
+=head1 READ-ONLY ACCESSORS
+
+=head2 B<originalEstimate>
+
+Returns the original estimate as a number of seconds in numeric context, and as a w/d/h/m/s string in a string context.
+
+=head2 B<remainingEstimate>
+
+Returns the remaining estimate as a number of seconds in numeric context, and as a w/d/h/m/s string in a string context.
+
+=head2 B<timeSpent>
+
+Returns the time spent as a number of seconds in numeric context, and as a w/d/h/m/s string in a string context.
+
+=head1 RELATED CLASSES
+
+=over 2
+
+=item * L<JIRA::REST::Class|JIRA::REST::Class>
+
+=item * L<JIRA::REST::Class::Abstract|JIRA::REST::Class::Abstract>
+
+=item * L<JIRA::REST::Class::Version|JIRA::REST::Class::Version>
+
+=back
+
 =head1 AUTHOR
 
 Packy Anderson <packy@cpan.org>
