@@ -1,31 +1,37 @@
 package JIRA::REST::Class::Issue::Transitions;
-use base qw( JIRA::REST::Class::Abstract );
+use parent qw( JIRA::REST::Class::Abstract );
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 
 use Carp;
 
 use JIRA::REST::Class::Version qw( $VERSION );
 
-# ABSTRACT: A helper class for C<JIRA::REST::Class> that represents the state transitions a JIRA issue can go through.
+# ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents the state transitions a JIRA issue can go through.
 
-__PACKAGE__->mk_contextual_ro_accessors(qw/ transitions /);
+__PACKAGE__->mk_contextual_ro_accessors( qw/ transitions / );
 
 sub init {
     my $self = shift;
-    $self->SUPER::init(@_);
+    $self->SUPER::init( @_ );
     $self->_refresh_transitions;
+    return;
 }
 
 sub _refresh_transitions {
     my $self = shift;
 
-    $self->{data} = $self->issue->get('/transitions?expand=transitions.fields');
+    $self->{data}
+        = $self->issue->get( '/transitions?expand=transitions.fields' );
 
-    $self->{transitions} = [ map {
-        $self->issue->make_object('transition', { data => $_ })
-    } @{ $self->data->{transitions} } ];
+    $self->{transitions} = [  #
+        map {                 #
+            $self->issue->make_object( 'transition', { data => $_ } )
+        } @{ $self->data->{transitions} }
+    ];
+
+    return;
 }
 
 #pod =internal_method B<find_transition_named>
@@ -36,7 +42,7 @@ sub _refresh_transitions {
 
 sub find_transition_named {
     my $self = shift;
-    my $name = shift or confess "no name specified";
+    my $name = shift or confess 'no name specified';
 
     $self->_refresh_transitions;
 
@@ -45,13 +51,12 @@ sub find_transition_named {
         return $transition;
     }
 
-    die sprintf(
-        "Unable to find transition '%s'\n".
-        "issue status: %s\n".
-        "transitions:  %s\n",
-        $name, $self->issue->status->name,
-        $self->dump([ $self->transitions ]),
-    );
+    croak sprintf "Unable to find transition '%s'\n"
+        . "issue status: %s\n"
+        . "transitions:  %s\n",
+        $name,
+        $self->issue->status->name,
+        $self->dump( [ $self->transitions ] );
 }
 
 #pod =method B<block>
@@ -60,7 +65,7 @@ sub find_transition_named {
 #pod
 #pod =cut
 
-sub block { shift->find_transition_named("Block Issue")->go(@_) }
+sub block { return shift->find_transition_named( 'Block Issue' )->go( @_ ) }
 
 #pod =method B<close>
 #pod
@@ -68,7 +73,9 @@ sub block { shift->find_transition_named("Block Issue")->go(@_) }
 #pod
 #pod =cut
 
-sub close { shift->find_transition_named("Close Issue")->go(@_) }
+## no critic (ProhibitBuiltinHomonyms ProhibitAmbiguousNames)
+sub close { return shift->find_transition_named( 'Close Issue' )->go( @_ ) }
+## use critic
 
 #pod =method B<verify>
 #pod
@@ -76,7 +83,7 @@ sub close { shift->find_transition_named("Close Issue")->go(@_) }
 #pod
 #pod =cut
 
-sub verify { shift->find_transition_named("Verify Issue")->go(@_) }
+sub verify { return shift->find_transition_named( 'Verify Issue' )->go( @_ ) }
 
 #pod =method B<resolve>
 #pod
@@ -84,7 +91,7 @@ sub verify { shift->find_transition_named("Verify Issue")->go(@_) }
 #pod
 #pod =cut
 
-sub resolve { shift->find_transition_named("Resolve Issue")->go(@_) }
+sub resolve { return shift->find_transition_named( 'Resolve Issue' )->go( @_ ) }
 
 #pod =method B<reopen>
 #pod
@@ -92,7 +99,7 @@ sub resolve { shift->find_transition_named("Resolve Issue")->go(@_) }
 #pod
 #pod =cut
 
-sub reopen { shift->find_transition_named("Reopen Issue")->go(@_) }
+sub reopen { return shift->find_transition_named( 'Reopen Issue' )->go( @_ ) }
 
 #pod =method B<start_progress>
 #pod
@@ -100,7 +107,9 @@ sub reopen { shift->find_transition_named("Reopen Issue")->go(@_) }
 #pod
 #pod =cut
 
-sub start_progress { shift->find_transition_named("Start Progress")->go(@_) }
+sub start_progress {
+    return shift->find_transition_named( 'Start Progress' )->go( @_ );
+}
 
 #pod =method B<stop_progress>
 #pod
@@ -108,7 +117,9 @@ sub start_progress { shift->find_transition_named("Start Progress")->go(@_) }
 #pod
 #pod =cut
 
-sub stop_progress { shift->find_transition_named("Stop Progress")->go(@_) }
+sub stop_progress {
+    return shift->find_transition_named( 'Stop Progress' )->go( @_ );
+}
 
 #pod =method B<start_qa>
 #pod
@@ -116,7 +127,7 @@ sub stop_progress { shift->find_transition_named("Stop Progress")->go(@_) }
 #pod
 #pod =cut
 
-sub start_qa { shift->find_transition_named("Start QA")->go(@_) }
+sub start_qa { return shift->find_transition_named( 'Start QA' )->go( @_ ) }
 
 #pod =method B<transition_walk>
 #pod
@@ -146,20 +157,20 @@ sub transition_walk {
     my $self     = shift;
     my $target   = shift;
     my $map      = shift;
-    my $callback = shift // sub {};
+    my $callback = shift // sub { };
     my $name     = $self->issue->status->name;
 
     my $orig_assignee = $self->issue->assignee // q{};
 
-    until ($name eq $target) {
-        if (exists $map->{$name} ) {
+    until ( $name eq $target ) {
+        if ( exists $map->{$name} ) {
             my $to = $map->{$name};
             unless ( exists $state_to_transition{$to} ) {
                 die "Unknown target state '$to'!\n";
             }
-            my $trans =
-                $self->find_transition_named( $state_to_transition{$to} );
-            $callback->($name, $to);
+            my $trans
+                = $self->find_transition_named( $state_to_transition{$to} );
+            $callback->( $name, $to );
             $trans->go;
         }
         else {
@@ -173,13 +184,28 @@ sub transition_walk {
     # put the owner back to who it's supposed
     # to be if it changed during our walk
     my $current_assignee = $self->issue->assignee // q{};
-    if ($current_assignee ne $orig_assignee) {
-        $self->issue->set_assignee($orig_assignee);
+    if ( $current_assignee ne $orig_assignee ) {
+        $self->issue->set_assignee( $orig_assignee );
     }
+
+    return;
 }
 
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod =head2 JIRA REST API Reference L<Do transition|https://docs.atlassian.com/jira/REST/latest/#api/2/issue-doTransition>
+#pod
+#pod The fields that can be set on transition, in either the fields parameter or the
+#pod update parameter can be determined using the
+#pod C</rest/api/2/issue/{issueIdOrKey}/transitions?expand=transitions.fields>
+#pod resource. If a field is not configured to appear on the transition screen, then
+#pod it will not be in the transition metadata, and a field validation error will
+#pod occur if it is submitted.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -190,11 +216,11 @@ __END__
 
 =head1 NAME
 
-JIRA::REST::Class::Issue::Transitions - A helper class for C<JIRA::REST::Class> that represents the state transitions a JIRA issue can go through.
+JIRA::REST::Class::Issue::Transitions - A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents the state transitions a JIRA issue can go through.
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 METHODS
 
@@ -247,6 +273,20 @@ This method takes three unnamed parameters:
 
 Returns the transition object for the named transition provided.
 
+=head1 RELATED CLASSES
+
+=over 2
+
+=item * L<JIRA::REST::Class|JIRA::REST::Class>
+
+=item * L<JIRA::REST::Class::Abstract|JIRA::REST::Class::Abstract>
+
+=item * L<JIRA::REST::Class::Issue::Transitions::Transition|JIRA::REST::Class::Issue::Transitions::Transition>
+
+=item * L<JIRA::REST::Class::Version|JIRA::REST::Class::Version>
+
+=back
+
 =head1 SEE ALSO
 
 =head2 JIRA REST API Reference L<Do transition|https://docs.atlassian.com/jira/REST/latest/#api/2/issue-doTransition>
