@@ -1,42 +1,45 @@
 package JIRA::REST::Class::Mixins;
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 
 use JIRA::REST::Class::Version qw( $VERSION );
 
-# ABSTRACT: An mixin class for C<JIRA::REST::Class> that other objects can inherit methods from.
+# ABSTRACT: An mixin class for L<JIRA::REST::Class|JIRA::REST::Class> that other objects can inherit methods from.
 
 use Carp;
 use Clone::Any qw( clone );
 use Data::Dumper::Concise;
 use MIME::Base64;
+use Readonly;
 use Scalar::Util qw( blessed reftype );
+use Try::Tiny;
 
 sub jira {
     my $self  = shift;
     my $args  = shift;
-    my $class = ref $self ? ref($self) : $self;
+    my $class = ref $self ? ref( $self ) : $self;
+
+    if ( blessed $self ) {
 
-    if (blessed $self) {
         # if we have an object, return it!
         return $self->{jira} if $self->{jira};
 
-        if (!$args && $self->{args}) {
+        if ( !$args && $self->{args} ) {
             $args = $self->{args};
         }
 
         # if we have arguments, call ourself using
         # the class name with those args, and cache the result
-        if ($args) {
-            $self->{jira}      = $class->jira($args);
+        if ( $args ) {
+            $self->{jira}      = $class->jira( $args );
             $self->{jira_rest} = $self->{jira}->{jira_rest};
             return $self->{jira};
         }
     }
 
     # called with just the class name
-    return JIRA::REST::Class->new($args);
+    return JIRA::REST::Class->new( $args );
 }
 
 #---------------------------------------------------------------------------
@@ -74,24 +77,25 @@ sub jira {
 sub factory {
     my $self  = shift;
     my $args  = shift;
-    my $class = ref $self ? ref($self) : $self;
+    my $class = ref $self ? ref( $self ) : $self;
+
+    if ( blessed $self ) {
 
-    if (blessed $self) {
         # if we have a factory, return it!
-        if ($self->{factory}) {
+        if ( $self->{factory} ) {
             return $self->{factory};
         }
 
         # if we have arguments, call ourself using
         # the class name with those args, and cache the result
-        if ($args) {
-            $self->{factory} = $class->factory($args);
+        if ( $args ) {
+            $self->{factory} = $class->factory( $args );
             return $self->{factory};
         }
     }
 
     # called with just the class name
-    return JIRA::REST::Class::Factory->new('factory', { args => $args });
+    return JIRA::REST::Class::Factory->new( 'factory', { args => $args } );
 }
 
 #---------------------------------------------------------------------------
@@ -117,12 +121,13 @@ sub factory {
 
 #---------------------------------------------------------------------------
 
-sub JIRA_REST {
-    my $self = shift;
-    my $args = shift;
-    my $class = ref $self ? ref($self) : $self;
+sub JIRA_REST { ## no critic (Capitalization)
+    my $self  = shift;
+    my $args  = shift;
+    my $class = ref $self ? ref( $self ) : $self;
+
+    if ( blessed $self ) {
 
-    if (blessed $self) {
         # method called on a class object
 
         # if we have a copy of the JIRA::REST object, return it!
@@ -130,31 +135,31 @@ sub JIRA_REST {
 
         # if we have arguments, call ourself using
         # the class name with those args, and cache the result
-        return $self->{jira_rest} = $class->JIRA_REST($args)
+        return $self->{jira_rest} = $class->JIRA_REST( $args )
             if $args;
     }
 
     # called with just the class name
 
     if ( _JIRA_REST_version_has_named_parameters() ) {
-        return JIRA::REST->new($args);
+        return JIRA::REST->new( $args );
     }
 
     # still support the old style arguments for JIRA::REST
-    my $jira_rest = JIRA::REST->new($args->{url},
-                                    $args->{username},
-                                    $args->{password},
-                                    $args->{rest_client_config});
+    my $jira_rest = JIRA::REST->new(
+        $args->{url},      $args->{username},
+        $args->{password}, $args->{rest_client_config}
+    );
 
     my $rest = $jira_rest->{rest};
     my $ua   = $rest->getUseragent;
-    $ua->ssl_opts(SSL_verify_mode => 0, verify_hostname => 0)
+    $ua->ssl_opts( SSL_verify_mode => 0, verify_hostname => 0 )
         if $args->{ssl_verify_none};
 
-    unless ($args->{username} && $args->{password}) {
-        if (my $auth = $rest->{_headers}->{Authorization}) {
-            my(undef, $encoded) = split /\s+/, $auth;
-            ($args->{username}, $args->{password}) =
+    unless ( $args->{username} && $args->{password} ) {
+        if ( my $auth = $rest->{_headers}->{Authorization} ) {
+            my ( undef, $encoded ) = split /\s+/, $auth;
+            ( $args->{username}, $args->{password} ) =  #
                 split /:/, decode_base64 $encoded;
         }
     }
@@ -162,78 +167,89 @@ sub JIRA_REST {
     return $jira_rest;
 }
 
-sub _JIRA_REST_version {
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
+## these are private to the whole module, not just this package
+sub _JIRA_REST_version { ## no critic (Capitalization)
     my $version = shift;
-    eval {
+    my $has_version;
+    try {
         # we don't want SIGDIE taking us someplace
         # if VERSION throws an exception
         local $SIG{__DIE__} = undef;
 
-        JIRA::REST->VERSION && JIRA::REST->VERSION($version);
+        $has_version = JIRA::REST->VERSION && JIRA::REST->VERSION( $version );
     };
+    return $has_version;
 }
 
-sub _JIRA_REST_version_has_named_parameters {
-    state $retval = _JIRA_REST_version(0.017);
+sub _JIRA_REST_version_has_named_parameters { ## no critic (Capitalization)
+    ## no critic (ProhibitMagicNumbers)
+    state $retval = _JIRA_REST_version( 0.017 );
+    ## use critic
     return $retval;
 }
 
-sub _JIRA_REST_version_has_separate_path {
-    state $retval = _JIRA_REST_version(0.015);
+sub _JIRA_REST_version_has_separate_path { ## no critic (Capitalization)
+    ## no critic (ProhibitMagicNumbers)
+    state $retval = _JIRA_REST_version( 0.015 );
+    ## use critic
     return $retval;
 }
+## use critic
 
-sub REST_CLIENT { shift->JIRA_REST->{rest} }
-sub JSON        { shift->JIRA_REST->{json} }
-sub make_object { shift->factory->make_object(@_) }
-sub make_date   { shift->factory->make_date(@_) }
-sub class_for   { shift->factory->get_factory_class(@_) }
+## no critic (Capitalization)
+sub REST_CLIENT { return shift->JIRA_REST->{rest} }
+sub JSON        { return shift->JIRA_REST->{json} }
+## use critic
+sub make_object { return shift->factory->make_object( @_ ) }
+sub make_date   { return shift->factory->make_date( @_ ) }
+sub class_for   { return shift->factory->get_factory_class( @_ ) }
 
-sub obj_isa  {
-    my ($self, $obj, $type) = @_;
+sub obj_isa {
+    my ( $self, $obj, $type ) = @_;
     return unless blessed $obj;
-    my $class = $self->class_for($type);
-    $obj->isa( $class );
+    my $class = $self->class_for( $type );
+    return $obj->isa( $class );
 }
 
 sub name_for_user {
-    my($self, $user) = @_;
-    return $self->obj_isa($user, 'user') ? $user->name : $user;
+    my ( $self, $user ) = @_;
+    return $self->obj_isa( $user, 'user' ) ? $user->name : $user;
 }
 
 sub key_for_issue {
-    my($self, $issue) = @_;
-    return $self->obj_isa($issue, 'issue') ? $issue->key : $issue;
+    my ( $self, $issue ) = @_;
+    return $self->obj_isa( $issue, 'issue' ) ? $issue->key : $issue;
 }
 
 sub find_link_name_and_direction {
-    my ($self, $link, $dir) = @_;
+    my ( $self, $link, $dir ) = @_;
 
     return unless defined $link;
 
     # determine the link directon, if provided. defaults to inward.
-    $dir = ($dir && $dir =~ /out(?:ward)?/) ? 'outward' : 'inward';
+    $dir = ( $dir && $dir =~ /out(?:ward)?/x ) ? 'outward' : 'inward';
 
     # if we were passed a link type object, return
     # the name and the direction we were given
-    if ( $self->obj_isa($link, 'linktype') ) {
+    if ( $self->obj_isa( $link, 'linktype' ) ) {
         return $link->name, $dir;
     }
 
     # search through the link types
- # work in progress
- #   my @types = $self->jira->link_types;
- #   foreach my $type ( @types ) {
- #       if (lc $link eq lc $type->inward) {
- #           return $type->name, 'inward';
- #       }
- #       if (lc $link eq lc $type->outward) {
- #           return $type->name, 'outward';
- #       }
- #       if (lc $link eq lc $type->name) {
- #           return $type->name, $dir;
- #       }
- #   }
+    # work in progress
+    #   my @types = $self->jira->link_types;
+    #   foreach my $type ( @types ) {
+    #       if (lc $link eq lc $type->inward) {
+    #           return $type->name, 'inward';
+    #       }
+    #       if (lc $link eq lc $type->outward) {
+    #           return $type->name, 'outward';
+    #       }
+    #       if (lc $link eq lc $type->name) {
+    #           return $type->name, $dir;
+    #       }
+    #   }
 
     # we didn't find anything, so just return what we were passed
     return $link, $dir;
@@ -241,21 +257,21 @@ sub find_link_name_and_direction {
 
 ###########################################################################
 
-sub dump {
-    my $self = shift;
+sub dump { ## no critic (ProhibitBuiltinHomonyms)
+    my ( $self, @args ) = @_;
     my $result;
-    if (@_) {
-        $result = $self->cosmetic_copy( @_ );
+    if ( @args ) {
+        $result = $self->cosmetic_copy( @args );
     }
     else {
         $result = $self->cosmetic_copy( $self );
     }
-    return ref($result) ? Dumper($result) : $result;
+    return ref( $result ) ? Dumper( $result ) : $result;
 }
 
 sub cosmetic_copy {
-    shift; # we don't need $self
-    return __cosmetic_copy(@_, 'top');
+    shift;  # we don't need $self
+    return __cosmetic_copy( @_, 'top' );
 }
 
 #---------------------------------------------------------------------------
@@ -290,46 +306,46 @@ sub cosmetic_copy {
 
 #---------------------------------------------------------------------------
 
-
 sub __cosmetic_copy {
     my $thing = shift;
     my $top   = pop;
 
-    if (not ref $thing) {
+    if ( not ref $thing ) {
         return $thing;
     }
 
-    my $hash_copy = sub {};
+    my $hash_copy = sub { };
 
     if ( my $class = blessed $thing ) {
-        if ($class eq 'JSON::PP::Boolean') {
+        if ( $class eq 'JSON::PP::Boolean' ) {
             return $thing ? 'JSON::PP::true' : 'JSON::PP::false';
         }
-        elsif ($class eq 'JSON') {
+        if ( $class eq 'JSON' ) {
             return "$thing";
         }
-        elsif ($class eq 'REST::Client') {
+        if ( $class eq 'REST::Client' ) {
             return '%s->host(%s)', $class, $thing->getHost;
         }
-        elsif ($class eq 'DateTime') {
+        if ( $class eq 'DateTime' ) {
             return "DateTime(  $thing  )";
         }
-        elsif ($top) {
-            if (reftype $thing eq 'ARRAY') {
-                chomp ( my $data = Dumper( __array_copy($thing) ) );
+        if ( $top ) {
+            if ( reftype $thing eq 'ARRAY' ) {
+                chomp( my $data = Dumper( __array_copy( $thing ) ) );
                 return "bless( $data => $class )";
             }
-            elsif (reftype $thing eq 'HASH') {
-                chomp ( my $data = Dumper( __hash_copy($thing) ) );
+            if ( reftype $thing eq 'HASH' ) {
+                chomp( my $data = Dumper( __hash_copy( $thing ) ) );
                 return "bless( $data => $class )";
             }
-            return Dumper($thing);
+            return Dumper( $thing );
         }
         else {
             my $fallback;
+
             # see if the object has any of these methods
-            foreach my $method (qw/ name key id /) {
-                if ( $thing->can($method) ) {
+            foreach my $method ( qw/ name key id / ) {
+                if ( $thing->can( $method ) ) {
                     my $value = $thing->$method;
 
                     # if the method returned a value, great!
@@ -347,31 +363,28 @@ sub __cosmetic_copy {
         }
     }
 
-    if (ref $thing eq 'SCALAR') {
+    if ( ref $thing eq 'SCALAR' ) {
         return $$thing;
     }
-    elsif (ref $thing eq 'ARRAY') {
-        return __array_copy($thing);
+    elsif ( ref $thing eq 'ARRAY' ) {
+        return __array_copy( $thing );
     }
-    elsif (ref $thing eq 'HASH') {
-        return __hash_copy($thing);
+    elsif ( ref $thing eq 'HASH' ) {
+        return __hash_copy( $thing );
     }
     return $thing;
 }
 
 sub __array_copy {
     my $thing = shift;
-    return [ map { __cosmetic_copy($_) } @{$thing} ];
+    return [ map { __cosmetic_copy( $_ ) } @$thing ];
 }
 
 sub __hash_copy {
     my $thing = shift;
-    return +{
-        map { $_ => __cosmetic_copy($thing->{$_}) } keys %{$thing}
-    };
+    return +{ map { $_ => __cosmetic_copy( $thing->{$_} ) } keys %$thing };
 }
 
-
 ###########################################################################
 #
 # internal helper functions
@@ -389,44 +402,46 @@ sub __hash_copy {
 #
 # In either case, the result hashref is returned.
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _get_known_args {
-    my $self = shift;
-    my $in   = shift;
-    my $out  = {};
-    my @args = @_;
+## use critic
+    my ( $self, $in, @args ) = @_;
+    my $out = {};
 
     # get the package->name of the sub that called US
-    my $sub = $self->__subname(caller(1));
+    my $sub = $self->__subname( caller 1 );
 
     # if we croak, croak from the perspective of our CALLER's caller
     local $Carp::CarpLevel = $Carp::CarpLevel + 2;
 
     # $in is an arrayref with a single hashref in it
-    if (@$in == 1 && ref $$in[0] && ref $$in[0] eq 'HASH') {
+    if ( @$in == 1 && ref $in->[0] && ref $in->[0] eq 'HASH' ) {
+
         # copy that hashref into $in
-        $in = clone($in->[0]);
+        $in = clone( $in->[0] );
 
         # moving arguments using the semi-magical hash reference slice
         @{$out}{@args} = delete @{$in}{@args};
 
         # if there are leftover keys
-        if (keys %$in) {
-            my $arguments = 'argument' . (keys %$in == 1 ? q{} : q{s});
+        if ( keys %$in ) {
+            my $arguments = 'argument' . ( keys %$in == 1 ? q{} : q{s} );
 
             croak "$sub: unknown $arguments - "
-                . $self->_quoted_list(sort keys %$in);
+                . $self->_quoted_list( sort keys %$in );
         }
     }
     else {
         # if there aren't more arguments than we have names for
-        if (@$in <= @args) {
+        if ( @$in <= @args ) {
+
             # copy arguments positionally
             @{$out}{@args} = @$in;
         }
         else {
             my $got  = scalar @$in;
             my $max  = scalar @args;
-            my $list = $self->_quoted_list(@args);
+            my $list = $self->_quoted_list( @args );
 
             croak "$sub: too many arguments - got $got, max $max ($list)";
         }
@@ -518,24 +533,26 @@ sub _get_known_args {
 
 # accepts a hashref and a list of required arguments
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _check_required_args {
-    my $self = shift;
-    my $args = shift;
-    my @args = @_;
+## use critic
+    my ( $self, $args, @args ) = @_;
 
-    while ( my($arg, $err) = splice @args, 0, 2 ) {
-        next if exists  $args->{$arg}
-             && defined $args->{$arg}
-             && length  $args->{$arg};
+    while ( my ( $arg, $err ) = splice @args, 0, 2 ) {
+        next
+            if exists $args->{$arg}
+            && defined $args->{$arg}
+            && length $args->{$arg};
 
         # get the package->name of the sub that called US
-        my $sub = $self->__subname(caller(1));
+        my $sub = $self->__subname( caller 1 );
 
         # croak from the perspective of our CALLER's caller
         local $Carp::CarpLevel = $Carp::CarpLevel + 2;
 
-        croak "$sub: ".$err;
+        croak "$sub: " . $err;
     }
+    return;
 }
 
 #---------------------------------------------------------------------------
@@ -566,13 +583,14 @@ sub _check_required_args {
 # internal function so I don't have to build a "Package->subroutine:" prefix
 # whenever I want to croak
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _croakmsg {
-    my $self = shift;
-    my $msg  = shift;
-    my $args = @_ ? q{(}.join(q{, },@_).q{)} : q{};
+## use critic
+    my ( $self, $msg, @args ) = @_;
+    my $args = @args ? q{(} . join( q{, }, @args ) . q{)} : q{};
 
     # get the package->name of the sub that called US
-    my $sub = $self->__subname(caller(1));
+    my $sub = $self->__subname( caller 1 );
 
     return join q{ }, "$sub$args:", $msg;
 }
@@ -613,7 +631,7 @@ sub _croakmsg {
 #
 sub _quoted_list {
     my $self = shift;
-    return q{'} . join(q{', '}, @_) . q{'};
+    return q{'} . join( q{', '}, @_ ) . q{'};
 }
 
 #
@@ -622,11 +640,13 @@ sub _quoted_list {
 #   returns 'Some::Pkg->subname'
 #
 sub __subname {
-    my($self, @callerN) = @_;
-    (my $sub = $callerN[3]) =~ s/(.*)::([^:]+)$/$1->$2/;
+    my ( $self, @caller_n ) = @_;
+    Readonly my $OUR_CALLERS_CALLER => 3;
+    ( my $sub = $caller_n[$OUR_CALLERS_CALLER] ) =~ s/(.*)::([^:]+)$/$1->$2/xs;
     return $sub;
 }
 
+# put a reference to JIRA::REST::Class::Abstract here for related classes
 
 1;
 
@@ -636,8 +656,8 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexey Melezhik jira Atlassian JRC ScriptRunner TODO
-aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
+=for :stopwords Packy Anderson Alexey Melezhik jira JRC Atlassian GreenHopper ScriptRunner
+TODO aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
 assigneeType avatar avatarUrls completeDate displayName duedate
 emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
 isAssigneeTypeValid issueTypes issuekeys issuelinks issuetype jql
@@ -649,90 +669,91 @@ toString updateAuthor worklog workratio
 
 =head1 NAME
 
-JIRA::REST::Class::Mixins - An mixin class for C<JIRA::REST::Class> that other objects can inherit methods from.
+JIRA::REST::Class::Mixins - An mixin class for L<JIRA::REST::Class|JIRA::REST::Class> that other objects can inherit methods from.
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 METHODS
 
 =head2 B<name_for_user>
 
-When passed a scalar that could be a C<JIRA::REST::Class::User>
-object, returns the name of the user if it is a
-C<JIRA::REST::Class::User> object, or the unmodified scalar if it is
-not.
+When passed a scalar that could be a
+L<JIRA::REST::Class::User|JIRA::REST::Class::User> object, returns the name
+of the user if it is a C<JIRA::REST::Class::User>
+object, or the unmodified scalar if it is not.
 
 =head2 B<key_for_issue>
 
-When passed a scalar that could be a C<JIRA::REST::Class::Issue>
-object, returns the key of the issue if it is a
-C<JIRA::REST::Class::Issue> object, or the unmodified scalar if it is
-not.
+When passed a scalar that could be a
+L<JIRA::REST::Class::Issue|JIRA::REST::Class::Issue> object, returns the key
+of the issue if it is a C<JIRA::REST::Class::Issue>
+object, or the unmodified scalar if it is not.
 
 =head2 B<find_link_name_and_direction>
 
 When passed two scalars, one that could be a
-C<JIRA::REST::Class::Issue::LinkType> object and another that is a
-direction (inward/outward), returns the name of the link type and
-direction if it is a C<JIRA::REST::Class::Issue::LinkType> object, or
-attempts to determine the link type and direction from the provided
-scalars.
+L<JIRA::REST::Class::Issue::LinkType|JIRA::REST::Class::Issue::LinkType>
+object and another that is a direction (inward/outward), returns the name of
+the link type and direction if it is a C<JIRA::REST::Class::Issue::LinkType>
+object, or attempts to determine the link type and direction from the
+provided scalars.
 
 =head2 B<dump>
 
-Returns a stringified representation of the object's data generated
-somewhat by Data::Dumper::Concise, but not descending into any objects
-that might be part of that data.  If it finds objects in the data, it
-will attempt to represent them in some abbreviated fashion which may
-not display all the data in the object.  For instance, if the object
-has a JIRA::REST::Class::Issue object in it for an issue with the key
-'JRC-1', the object would be represented as the string
-'JIRA::REST::Class::Issue->key(JRC-1)'.  The goal is to provide a gist
-of what the contents of the object are without exhaustively dumping
-EVERYTHING.
+Returns a stringified representation of the object's data generated somewhat
+by L<Data::Dumper::Concise|Data::Dumper::Concise>, but not descending into
+any objects that might be part of that data.  If it finds objects in the
+data, it will attempt to represent them in some abbreviated fashion which
+may not display all the data in the object.  For instance, if the object has
+a C<JIRA::REST::Class::Issue> object in it for an issue with the key
+C<'JRC-1'>, the object would be represented as the string C<<
+'JIRA::REST::Class::Issue->key(JRC-1)' >>.  The goal is to provide a gist of
+what the contents of the object are without exhaustively dumping EVERYTHING.
+I use it a lot for figuring out what's in the results I'm getting back from
+the JIRA API.
 
 =head1 INTERNAL METHODS
 
 =head2 B<jira>
 
-Returns a C<JIRA::REST::Class> object with credentials for the last JIRA user.
+Returns a L<JIRA::REST::Class|JIRA::REST::Class> object with credentials for the last JIRA user.
 
 =head2 B<factory>
 
-An accessor for the C<JIRA::REST::Class::Factory>.
+An accessor for the L<JIRA::REST::Class::Factory|JIRA::REST::Class::Factory>.
 
 =head2 B<JIRA_REST>
 
-An accessor that returns the C<JIRA::REST> object being used.
+An accessor that returns the L<JIRA::REST|JIRA::REST> object being used.
 
 =head2 B<REST_CLIENT>
 
-An accessor that returns the C<REST::Client> object inside the C<JIRA::REST> object being used.
+An accessor that returns the L<REST::Client|REST::Client> object inside the L<JIRA::REST|JIRA::REST> object being used.
 
 =head2 B<JSON>
 
-An accessor that returns the C<JSON> object inside the C<JIRA::REST> object being used.
+An accessor that returns the L<JSON|JSON> object inside the L<JIRA::REST|JIRA::REST> object being used.
 
 =head2 B<make_object>
 
-A pass-through method that calls C<JIRA::REST::Class::Factory::make_object()>.
+A pass-through method that calls L<JIRA::REST::Class::Factory::make_object()|JIRA::REST::Class::Factory/make_object>.
 
 =head2 B<make_date>
 
-A pass-through method that calls C<JIRA::REST::Class::Factory::make_date()>.
+A pass-through method that calls L<JIRA::REST::Class::Factory::make_date()|JIRA::REST::Class::Factory/make_date>.
 
 =head2 B<class_for>
 
-A pass-through method that calls C<JIRA::REST::Class::Factory::get_factory_class()>.
+A pass-through method that calls L<JIRA::REST::Class::Factory::get_factory_class()|JIRA::REST::Class::Factory/get_factory_class>.
 
 =head2 B<obj_isa>
 
 When passed a scalar that I<could> be an object and a class string,
 returns whether the scalar is, in fact, an object of that class.
 Looks up the actual class using C<class_for()>, which calls
-C<JIRA::REST::Class::Factory::get_factory_class()>.
+L<JIRA::REST::Class::Factory::get_factory_class()|JIRA::REST::Class::Factory/get_factory_class>.
 
 =head2 B<cosmetic_copy> I<THING>
 
@@ -740,12 +761,30 @@ A utility function to produce a "cosmetic" copy of a thing: it clones
 the data structure, but if anything in the structure (other than the
 structure itself) is a blessed object, it replaces it with a
 stringification of that object that probably doesn't contain all the
-data in the object. For instance, if the data structure has a
-JIRA::REST::Class::Issue object in it for an issue with the key
-'JRC-1', the object would be represented as the string
-'JIRA::REST::Class::Issue->key(JRC-1)'.  The goal is to provide a gist
-of what the contents of the data structure are without exhaustively
-dumping EVERYTHING.
+data in the object.  For instance, if the object has a
+C<JIRA::REST::Class::Issue> object in it for an issue with the key
+C<'JRC-1'>, the object would be represented as the string
+C<< 'JIRA::REST::Class::Issue->key(JRC-1)' >>.  The goal is to provide a
+gist of what the contents of the object are without exhaustively dumping
+EVERYTHING.
+
+=head1 RELATED CLASSES
+
+=over 2
+
+=item * L<JIRA::REST::Class|JIRA::REST::Class>
+
+=item * L<JIRA::REST::Class::Abstract|JIRA::REST::Class::Abstract>
+
+=item * L<JIRA::REST::Class::Factory|JIRA::REST::Class::Factory>
+
+=item * L<JIRA::REST::Class::FactoryTypes|JIRA::REST::Class::FactoryTypes>
+
+=item * L<JIRA::REST::Class::Project|JIRA::REST::Class::Project>
+
+=item * L<JIRA::REST::Class::Version|JIRA::REST::Class::Version>
+
+=back
 
 =begin test setup
 
