@@ -1,31 +1,40 @@
 package JIRA::REST::Class::Sprint;
-use base qw( JIRA::REST::Class::Abstract );
+use parent qw( JIRA::REST::Class::Abstract );
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 
 use JIRA::REST::Class::Version qw( $VERSION );
 
-# ABSTRACT: A helper class for C<JIRA::REST::Class> that represents the sprint of a JIRA issue as an object.
+# ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents the sprint of a JIRA issue as an object (if you're using L<Atlassian GreenHopper|https://www.atlassian.com/software/jira/agile>).
 
-__PACKAGE__->mk_ro_accessors(qw/ id rapidViewId state name startDate endDate
-                                 completeDate sequence /);
+use Readonly;
+
+Readonly my @ACCESSORS => qw( id rapidViewId state name startDate endDate
+                              completeDate sequence );
+
+__PACKAGE__->mk_ro_accessors( @ACCESSORS );
+
+Readonly my $GREENHOPPER_SPRINT => qr{ com [.] atlassian [.] greenhopper [.]
+                                       service [.] sprint [.] Sprint }x;
 
 sub init {
     my $self = shift;
-    $self->SUPER::init(@_);
+    $self->SUPER::init( @_ );
 
     my $data = $self->data;
-    $data =~ s{com\.atlassian\.greenhopper\.service\.sprint\.Sprint[^\[]+\[}{};
-    $data =~ s{\]$}{};
+    $data =~ s{ $GREENHOPPER_SPRINT [ ^ \[ ]+ \[ }{}x;
+    $data =~ s{\]$}{}x;
     my @fields = split /,/, $data;
-    foreach my $field (@fields) {
-        my ($k, $v) = split /=/, $field;
-        if ($v && $v eq '<null>') {
+    foreach my $field ( @fields ) {
+        my ( $k, $v ) = split /=/, $field;
+        if ( $v && $v eq '<null>' ) {
             undef $v;
         }
         $self->{$k} = $v;
     }
+
+    return;
 }
 
 1;
@@ -36,7 +45,7 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexey Melezhik Atlassian JRC ScriptRunner TODO
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian GreenHopper JRC ScriptRunner TODO
 aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
 assigneeType avatar avatarUrls completeDate displayName duedate
 emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
@@ -49,11 +58,11 @@ toString updateAuthor worklog workratio
 
 =head1 NAME
 
-JIRA::REST::Class::Sprint - A helper class for C<JIRA::REST::Class> that represents the sprint of a JIRA issue as an object.
+JIRA::REST::Class::Sprint - A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents the sprint of a JIRA issue as an object (if you're using L<Atlassian GreenHopper|https://www.atlassian.com/software/jira/agile>).
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 READ-ONLY ACCESSORS
 
@@ -73,6 +82,18 @@ version 0.04
 
 =head2 B<sequence>
 
+=head1 RELATED CLASSES
+
+=over 2
+
+=item * L<JIRA::REST::Class|JIRA::REST::Class>
+
+=item * L<JIRA::REST::Class::Abstract|JIRA::REST::Class::Abstract>
+
+=item * L<JIRA::REST::Class::Version|JIRA::REST::Class::Version>
+
+=back
+
 # These methods don't work, probably because JIRA doesn't have a well-defined
 # interface for adding/removing issues from a sprint.
 
