@@ -1,24 +1,63 @@
 package JIRA::REST::Class::User;
-use base qw( JIRA::REST::Class::Abstract );
+use parent qw( JIRA::REST::Class::Abstract );
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 
 use JIRA::REST::Class::Version qw( $VERSION );
 
-# ABSTRACT: A helper class for C<JIRA::REST::Class> that represents a JIRA user as an object.
+# ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents a JIRA user as an object.
 
-__PACKAGE__->mk_data_ro_accessors(qw( active avatarUrls displayName emailAddress key name self timeZone));
+use Readonly;
+
+Readonly my @ACCESSORS => qw( active avatarUrls displayName emailAddress key
+                              name self timeZone );
+
+__PACKAGE__->mk_data_ro_accessors( @ACCESSORS );
 
 1;
 
+#pod =accessor B<active>
+#pod
+#pod A boolean indicating whether or not the user is active.
+#pod
+#pod =accessor B<avatarUrls>
+#pod
+#pod A hashref of the different sizes available for the project's avatar.
+#pod
+#pod =accessor B<displayName>
+#pod
+#pod The display name of the user.
+#pod
+#pod =accessor B<emailAddress>
+#pod
+#pod The email address of the user.
+#pod
+#pod =accessor B<key>
+#pod
+#pod The key for the user.
+#pod
+#pod =accessor B<name>
+#pod
+#pod The short name of the user.
+#pod
+#pod =accessor B<self>
+#pod
+#pod The URL of the JIRA REST API for the user
+#pod
+#pod =accessor B<timeZone>
+#pod
+#pod The home time zone of the user.
+#pod
+#pod =cut
+
 __END__
 
 =pod
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexey Melezhik Atlassian JRC ScriptRunner TODO
+=for :stopwords Packy Anderson Alexey Melezhik Atlassian GreenHopper JRC ScriptRunner TODO
 aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
 assigneeType avatar avatarUrls completeDate displayName duedate
 emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
@@ -31,13 +70,13 @@ toString updateAuthor worklog workratio
 
 =head1 NAME
 
-JIRA::REST::Class::User - A helper class for C<JIRA::REST::Class> that represents a JIRA user as an object.
+JIRA::REST::Class::User - A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents a JIRA user as an object.
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
-=head1 METHODS
+=head1 READ-ONLY ACCESSORS
 
 =head2 B<active>
 
@@ -71,6 +110,18 @@ The URL of the JIRA REST API for the user
 
 The home time zone of the user.
 
+=head1 RELATED CLASSES
+
+=over 2
+
+=item * L<JIRA::REST::Class|JIRA::REST::Class>
+
+=item * L<JIRA::REST::Class::Abstract|JIRA::REST::Class::Abstract>
+
+=item * L<JIRA::REST::Class::Version|JIRA::REST::Class::Version>
+
+=back
+
 =head1 AUTHOR
 
 Packy Anderson <packy@cpan.org>
